---
title: <span class="badge object-type-scalar"></span> Petabytes
---
# <span class="badge object-type-scalar"></span> Petabytes

Data: petabytes

## Definition

```python
# Data: petabytes
Petabytes: typing.Literal["decpbytes"] = "decpbytes"
```
